@@ -727,7 +727,8 @@ xlsx_get_axid (XLSXWriteState *state, GogAxis *axis)
 
 
 static void
-xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogPlot *plot, GogAxis *axis)
+xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml,
+		 GogPlot *plot, XLSXPlotType plot_type, GogAxis *axis)
 {
 	GogAxisType at = gog_axis_get_atype (axis);
 	GogAxis *crossed = gog_axis_base_get_crossed_axis_for_plot (GOG_AXIS_BASE (axis), plot);
@@ -738,6 +739,7 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogPlot *plot, GogAxis *
 	double d;
 	gboolean user_defined;
 	char *map_name;
+	const char *axis_tag = NULL;
 
 #ifdef DEBUG_AXIS
 	g_printerr ("Writing axis %s [id=%d].  (discrete = %d)\n",
@@ -751,10 +753,26 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogPlot *plot, GogAxis *
 		      "map-name", &map_name,
 		      NULL);
 
-	if (gog_axis_is_discrete (axis))
-		gsf_xml_out_start_element (xml, "c:catAx");
-	else
-		gsf_xml_out_start_element (xml, "c:valAx");
+	switch (plot_type) {
+	case XLSX_PT_GOGCONTOURPLOT:
+	case XLSX_PT_XLCONTOURPLOT:
+		// Both X and Y axes are discrete, but XL wants valAx for the
+		// X axis.
+		switch (at) {
+		case GOG_AXIS_X: axis_tag = "c:valAx"; break;
+		case GOG_AXIS_Y: axis_tag = "c:catAx"; break;
+		case GOG_AXIS_PSEUDO_3D: axis_tag = "c:serAx"; break;
+		default: g_assert_not_reached ();
+		}
+		break;
+	default:
+		break;
+	}
+
+	if (!axis_tag)
+		axis_tag = gog_axis_is_discrete (axis) ? "c:catAx" : "c:valAx";
+
+	gsf_xml_out_start_element (xml, axis_tag);
 	xlsx_write_chart_uint (xml, "c:axId", xlsx_get_axid (state, axis));
 
 	gsf_xml_out_start_element (xml, "c:scaling");
@@ -1003,8 +1021,15 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml,
 
 	case XLSX_PT_GOGCONTOURPLOT:
 	case XLSX_PT_XLCONTOURPLOT:
+		axis_type[2] = GOG_AXIS_PSEUDO_3D;
 		gsf_xml_out_start_element (xml, "c:surfaceChart");
 		break;
+
+	case XLSX_PT_GOGSURFACEPLOT:
+	case XLSX_PT_XLSURFACEPLOT:
+		axis_type[2] = GOG_AXIS_Z;
+		gsf_xml_out_start_element (xml, "c:surface3DChart");
+		break;
 	}
 
 	for (series = gog_plot_get_series (GOG_PLOT (plot));
@@ -1065,15 +1090,18 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml,
 			GogObject *eq;
 			GOData *dat;
 			char *name;
+			double intercept = gnm_nan;
 
 			if (!GOG_IS_TREND_LINE (trend))
 				continue;
 
 			if (strcmp (trend_type_name, "GogExpRegCurve") == 0)
 				trend_type = "exp";
-			else if (strcmp (trend_type_name, "GogLinRegCurve") == 0)
+			else if (strcmp (trend_type_name, "GogLinRegCurve") == 0) {
 				trend_type = "linear";
-			else if (strcmp (trend_type_name, "GogLogRegCurve") == 0)
+				if (!gnm_object_get_bool (trend, "affine"))
+					intercept = 0;
+			} else if (strcmp (trend_type_name, "GogLogRegCurve") == 0)
 				trend_type = "log";
 			else if (strcmp (trend_type_name, "GogMovingAvg") == 0)
 				trend_type = "movingAvg";
@@ -1088,12 +1116,16 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml,
 
 			gsf_xml_out_start_element (xml, "c:trendline");
 			dat = gog_dataset_get_dim (GOG_DATASET (trend), -1);
-			name = go_data_get_scalar_string (dat);
-			gsf_xml_out_simple_element (xml, "c:name", name);
-			g_free (name);
+			if (dat) {
+				char *name = go_data_get_scalar_string (dat);
+				gsf_xml_out_simple_element (xml, "c:name", name);
+				g_free (name);
+			}
 			xlsx_write_go_style (xml, state, go_styled_object_get_style (GO_STYLED_OBJECT (trend)));
 			xlsx_write_chart_cstr_unchecked (xml, "c:trendlineType", trend_type);
-			gsf_xml_out_end_element (xml); /* </c:trendline> */
+
+			if (!gnm_isnan (intercept))
+				xlsx_write_chart_float (xml, "c:intercept", intercept);
 
 			eq = gog_object_get_child_by_name (trend, "Equation");
 			if (eq) {
@@ -1104,6 +1136,8 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml,
 				if (has_eq)
 					xlsx_write_chart_bool (xml, "c:dispEq", TRUE);
 			}
+
+			gsf_xml_out_end_element (xml); /* </c:trendline> */
 		}
 		g_slist_free (children);
 
@@ -1208,14 +1242,13 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml,
 }
 
 static void
-xlsx_write_plots (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *chart, int *ser_count)
+xlsx_write_plots (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *chart,
+		  GSList *plots, int *ser_count)
 {
-	GSList *plots, *l;
-	GogObjectRole const *role = gog_object_find_role_by_name (GOG_OBJECT (chart), "Plot");
+	GSList *l;
 	GHashTable *axis_to_plot = g_hash_table_new (NULL, NULL);
 	GSList *axes = NULL;
 
-	plots = gog_object_get_children (GOG_OBJECT (chart), role);
 	for (l = plots; l; l = l->next) {
 		GogPlot *plot = l->data;
 		GSList *plot_axes, *al;
@@ -1230,12 +1263,13 @@ xlsx_write_plots (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *chart,
 		}
 		g_slist_free (plot_axes);
 	}
-	g_slist_free (plots);
 
 	for (l = axes; l; l = l->next) {
 		GogAxis *axis = l->data;
 		GogPlot *plot = g_hash_table_lookup (axis_to_plot, axis);
-		xlsx_write_axis (state, xml, plot, axis);
+		const char *plot_type_name = G_OBJECT_TYPE_NAME (plot);
+		XLSXPlotType plot_type = xlsx_plottype_from_type_name (plot_type_name);
+		xlsx_write_axis (state, xml, plot, plot_type, axis);
 	}
 	g_slist_free (axes);
 	g_hash_table_destroy (axis_to_plot);
@@ -1246,6 +1280,9 @@ xlsx_write_one_chart (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *ch
 {
 	GogObject const *obj;
 	int ser_count = 0;
+	GogObjectRole const *role;
+	GSList *plots, *l;
+	gboolean done;
 
 	gsf_xml_out_start_element (xml, "c:chart");
 
@@ -1259,10 +1296,32 @@ xlsx_write_one_chart (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *ch
 		}
 	}
 
+	role = gog_object_find_role_by_name (GOG_OBJECT (chart), "Plot");
+	plots = gog_object_get_children (GOG_OBJECT (chart), role);
+
+	for (l = plots, done = FALSE; l && !done; l = l->next) {
+		GogPlot *plot = l->data;
+		const char *plot_type_name = G_OBJECT_TYPE_NAME (plot);
+		XLSXPlotType plot_type = xlsx_plottype_from_type_name (plot_type_name);
+		switch (plot_type) {
+		case XLSX_PT_GOGCONTOURPLOT:
+		case XLSX_PT_XLCONTOURPLOT:
+			// XL wants a 3D view for a 2D chart
+			gsf_xml_out_start_element (xml, "c:view3D");
+			xlsx_write_chart_float (xml, "c:rotX", 90);
+			xlsx_write_chart_float (xml, "c:rotY", 0);
+			xlsx_write_chart_float (xml, "c:rAngAx", 0);
+			xlsx_write_chart_float (xml, "c:perspective", 0);
+			gsf_xml_out_end_element (xml);
+			done = TRUE;
+			break;
+		}
+	}
+
 	gsf_xml_out_start_element (xml, "c:plotArea");
 	/* save grid style here */
 
-	xlsx_write_plots (state, xml, chart, &ser_count);
+	xlsx_write_plots (state, xml, chart, plots, &ser_count);
 
 	obj = gog_object_get_child_by_name (GOG_OBJECT (chart), "Backplane");
 	if (obj) {
@@ -1275,6 +1334,7 @@ xlsx_write_one_chart (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *ch
 	}
 
 	gsf_xml_out_end_element (xml); /* </c:plotArea> */
+	g_slist_free (plots);
 
 	if ((obj = gog_object_get_child_by_name (chart, "Legend"))) {
 		char const *str;
