@@ -440,9 +440,7 @@ item_grid_draw_region (GocItem const *item, cairo_t *cr,
 	WorkbookView *wbv = sv_wbv (sv);
 	gboolean show_function_cell_markers = wbv->show_function_cell_markers;
 	gboolean show_extension_markers = wbv->show_extension_markers;
-	 /* we use the selected background color from an entry for selected cells */
-	GtkWidget *entry = gtk_entry_new ();
-	GtkStyleContext *ctxt = gtk_widget_get_style_context (entry);
+	GtkStyleContext *ctxt = goc_item_get_style_context (item);
 
 	/* To ensure that far and near borders get drawn we pretend to draw +-2
 	 * pixels around the target area which would include the surrounding
@@ -521,13 +519,13 @@ item_grid_draw_region (GocItem const *item, cairo_t *cr,
 	/* Fill entire region with default background (even past far edge) */
 	cairo_save (cr);
 	if (canvas->direction == GOC_DIRECTION_LTR)
-		gtk_render_background (goc_item_get_style_context (item),
+		gtk_render_background (ctxt,
 				       cr,
 				       x0 - canvas->scroll_x1 * scale,
 				       y0 - canvas->scroll_y1 * scale,
 				       width, height);
 	else
-		gtk_render_background (goc_item_get_style_context (item),
+		gtk_render_background (ctxt,
 				       cr,
 				       canvas->width - x0 + canvas->scroll_x1 * scale - width,
 				       y0 - canvas->scroll_y1 * scale,
@@ -852,9 +850,6 @@ plain_draw : /* a quick hack to deal with 142267 */
 			ig_cairo_draw_bound (ig, cr, 1, start_y, 1, y);
 	}
 
-	g_object_ref_sink (entry);
-	g_object_unref (entry);
-
 	g_slist_free (merged_used);	   /* merges with bottom in view */
 	g_slist_free (merged_active_seen); /* merges with bottom the view */
 	g_slist_free (merged_unused);	   /* merges in hidden rows */
@@ -1060,7 +1055,7 @@ cb_cursor_come_to_rest (GnmItemGrid *ig)
 	Sheet const *sheet = scg_sheet (ig->scg);
 	GocCanvas *canvas = ig->canvas_item.canvas;
 	GnmPane *pane = GNM_PANE (canvas);
-	GnmHLink *link;
+	GnmHLink *lnk;
 	gint64 x, y;
 	GnmCellPos pos;
 	char const *tiptext;
@@ -1072,9 +1067,9 @@ cb_cursor_come_to_rest (GnmItemGrid *ig)
 	pos.col = gnm_pane_find_col (pane, x, NULL);
 	pos.row = gnm_pane_find_row (pane, y, NULL);
 
-	link = gnm_sheet_hlink_find (sheet, &pos);
-	if (link != NULL && (tiptext = gnm_hlink_get_tip (link)) != NULL) {
-		g_return_val_if_fail (link == ig->cur_link, FALSE);
+	lnk = gnm_sheet_hlink_find (sheet, &pos);
+	if (lnk != NULL && (tiptext = gnm_hlink_get_tip (lnk)) != NULL) {
+		g_return_val_if_fail (lnk == ig->cur_link, FALSE);
 
 		if (ig->tip == NULL && strlen (tiptext) > 0) {
 			GtkWidget *cw = GTK_WIDGET (canvas);
@@ -1178,11 +1173,11 @@ item_grid_button_released (GocItem *item, int button, G_GNUC_UNUSED double x_, G
 	if (selecting == GNM_ITEM_GRID_SELECTING_CELL_RANGE && button == 1) {
 		GnmCellPos const *pos = sv_is_singleton_selected (scg_view (scg));
 		if (pos != NULL) {
-			GnmHLink *link;
+			GnmHLink *lnk;
 			/* check for hyper links */
-			link = gnm_sheet_hlink_find (sheet, pos);
-			if (link != NULL)
-				gnm_hlink_activate (link, scg_wbcg (scg));
+			lnk = gnm_sheet_hlink_find (sheet, pos);
+			if (lnk != NULL)
+				gnm_hlink_activate (lnk, scg_wbcg (scg));
 		}
 	}
 	return TRUE;
